@@ -75,6 +75,8 @@ _RELEASES = {
     'U': 'Ussuri',
     'V': 'Victoria',
     'W': 'Wallaby',
+    'X': 'Xena',
+    'Y': 'Yoga',
 }
 
 
@@ -155,6 +157,8 @@ class deprecated(object):
     USSURI = 'U'
     VICTORIA = 'V'
     WALLABY = 'W'
+    XENA = 'X'
+    YOGA = 'Y'
 
     def __init__(self, as_of, in_favor_of=None, remove_in=2, what=None):
         """Initialize decorator
